BleStatusCode class

Constructors

BleStatusCode({int statusCode = 500, bool isValid = false, bool isBodyTruncated = false, bool isHeadersTruncated = false})
BleStatusCode.fromJson(dynamic json)

Properties

hashCode int
The hash code for this object.
no setterinherited
isBodyTruncated bool
latefinal
isHeadersTruncated bool
latefinal
isValid bool
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited